Cross Validation for Sequential BATTing
cv.seqlr.batting(
y,
x,
censor.vec = NULL,
trt.vec = NULL,
trtref = NULL,
type = "c",
n.boot = 50,
des.res = "larger",
class.wt = c(1, 1),
min.sigp.prcnt = 0.2,
pre.filter = NULL,
filter.method = NULL,
k.fold = 5,
cv.iter = 50,
max.iter = 500
)a list containing with following entries:
Summary of performance statistics.
Data frame containing the predictive clases (TRUE/FALSE) for each iteration.
Data frame containing the fold indices (index of the fold for each row) for each iteration.
List of length cv.iter * k.fold containing the signature generated at each of the k folds, for all iterations.
List of any error messages that are returned at an iteration.
Treatment*subgroup interaction plot for predictive case
data frame containing the response
data frame containing the predictors
vector giving the censor status (only for TTE data , censor=0,event=1) : default = NULL
vector containing values of treatment variable ( for predictive signature). Set trt.vec to NULL for prognostic signature.
code for treatment arm.
data type. "c" - continuous , "b" - binary, "s" - time to event : default = "c".
number of bootstraps in BATTing step.
the desired response. "larger": prefer larger response. "smaller": prefer smaller response
vector of length 2 used to weight the accuracy score , useful when there is class imbalance in binary data defaults to c(1,1)
desired proportion of signature positive group size for a given cutoff.
NULL, no prefiltering conducted;"opt", optimized number of predictors selected; An integer: min(opt, integer) of predictors selected.
NULL, no prefiltering, "univariate", univaraite filtering; "glmnet", glmnet filtering, "unicart": univariate rpart filtering for prognostic case.
number of folds for CV.
algorithm terminates after cv.iter successful iterations of cross-validation.
total number of iterations allowed (including unsuccessful ones).
Cross Validation for Sequential BATTing