prefilter_variables: prefilter_variables

View source: R/prefilter_variables.R

prefilter_variablesR Documentation

prefilter_variables

Description

Pre-filter function for prognostic and predictive biomarker signature development for Exploratory Subgroup Identification in Randomized Clinical Trials

Usage

prefilter_variables(
  data,
  type = "c",
  yvar,
  xvars,
  censorvar = NULL,
  trtvar = NULL,
  trtref = 1,
  n.boot = 50,
  cv.iter = 20,
  pre.filter = length(xvars),
  filter.method = NULL
)

Arguments

data

input data frame

type

type of response variable: "c" continuous; "s" survival; "b" binary

yvar

variable (column) name for response variable

xvars

vector of variable names for predictors (covariates)

censorvar

variable name for censoring (1: event; 0: censor), default = NULL

trtvar

variable name for treatment variable, default = NULL (prognostic signature)

trtref

coding (in the column of trtvar) for treatment arm, default = 1 (no use for prognostic signature)

n.boot

number of bootstrap for the BATTing procedure

cv.iter

Algotithm terminates after cv.iter successful iterations of cross-validation, or after max.iter total iterations, whichever occurs first

pre.filter

NULL (default), no prefiltering conducted;"opt", optimized number of predictors selected; An integer: min(opt, integer) of predictors selected

filter.method

NULL (default), no prefiltering; "univariate", univaraite filtering; "glmnet", glmnet filtering

Details

Pre-filter predictor variables for biomarker signature development

The function contains two algorithms for filtering high-dimentional multivariate (prognostic/predictive) biomarker candidates via univariate fitering (used p-values of group difference for prognostic case, p-values of interaction term for predictive case); LASSO/Elastic Net method. (Tian L. et al 2012)

Value

var

a vector of filter results of variable names

References

Tian L, Alizadeh A, Gentles A, Tibshirani R (2012) A Simple Method for Detecting Interactions between a Treatment and a Large Number of Covariates. J Am Stat Assoc. 2014 Oct; 109(508): 1517-1532.

Examples

# no run

SubgrpID documentation built on March 7, 2026, 9:06 a.m.