Find cutoff for predictive case.
seqlr.find.cutoff.pred(
data,
yvar,
censorvar,
xvar,
trtvar,
type,
class.wt,
dir,
nsubj,
min.sigp.prcnt
)the optimal score (p-value of subgroup*treatment interaction) for a predictor variable.
input data frame.
response variable name.
censoring variable name.
name of predictor for which cutpoint needs to be obtained.
treatment variable name.
"c" continuous; "s" survival; "b" binary.
vector of length 2 used to weight the accuracy score , useful when there is class imbalance in binary data defaults to c(1,1).
direction of cut.
number of subjects.
desired proportion of signature positive group size for a given cutoff.
Find cutoff for predictive case.